<!-- Please remove check-list items that aren't relevant to your changes -->

- [ ] Closes #xxxx
- [ ] Tests added
- [ ] Documentation reflects changes
- [ ] PEP8 Standards or use of linter
- [ ] Xarray Dataset or DataArray variable naming follows 'ds' or 'da' naming
